% function Q=Qmatrix(qbanks, nu)
%
% qbanks : frequencies
% nu     : number of waves
%
% each row k in Q contains a windowed Fourier atom, with a frequency 
% qbanks[k], and a window with a size such that nu waves are considered:
% size nu*2*pi/qbanks[k].
%
% copyright (C) 2005 Bert Greevenbosch

function Q=Qmatrix(qbanks, nu)

  minfreq=min(qbanks);
  norows=length(qbanks);  
  nocols=round(2*nu*pi/minfreq);

  Q=zeros(norows, nocols);
  disp(sprintf('Creating %d x %d Q matrix', norows, nocols));
  totmx=0;
  for k=1:norows
    f=qbanks(k);
    mx=round(nu*pi/f);
    Q(k, 1:mx)=exp(i*f*(0:mx-1)).*cos((0:mx-1)*pi/(2*mx)).^2/sqrt(2*mx);
    Q(k, nocols-mx+1:nocols)=exp(i*f*(-mx:-1)).*cos((-mx:-1)*pi/(2*mx)).^2/sqrt(2*mx);
    disp(sprintf('%1.5f', k/norows));
    totmx=totmx+mx;
  end
  totmx=totmx*2;
  disp(sprintf('Average length: %d', round(totmx/norows)));
  
  Q=sparse(Q);
