% function y=pv(x, N, overlap, stretch)
%
% an implementation of the phase vocoder
%
% x       : input signal
% N       : window size
% overlap : overlap factor between two successive windows (for example .75)
% stretch : amount of time stretching
%
% copyright (C) 2005 Bert Greevenbosch

function y=pv(x, N, overlap, stretch)
   
   x=torow(x);
   window=sin((0:N-1)*pi/N).^2;
   dx=round(N*(1-overlap));
   dy=round(dx*stretch);
   stretch=dy/dx;
   disp(sprintf('Real stretching factor: %1.5f', stretch));
   y=zeros(round(length(x)*stretch), 1);
   nx=N/2+1;
   ny=round(nx*stretch);
   grain=x(nx-N/2:nx+N/2-1).*window;
   f=fft(fftshift(grain));
   f=f(1:N/2+1);
   phi1=angle(f);
   A1=abs(f);
   A=A1;
   nx=nx+dx;
   dpsi=(0:N/2)*dx*2*pi/N;
   phi=phi1;
   while(nx<length(x)-N/2)
      phi1=princarg(phi1);
      grain=x(nx-N/2:nx+N/2-1).*window;
      f=fft(fftshift(grain)); 
      f=f(1:N/2+1);
      phi2=princarg(angle(f));
      A2=abs(f);
      psi=phi1+dpsi;
      phi2=psi+princarg(phi2-psi);      
      dphi=(phi2-phi1)/dx;
      dA=(A2-A1)/dy;      
      for k=0:dy-1
         y(ny)=A*cos(phi)';
         A=A+dA;
         phi=phi+dphi;         
         ny=ny+1;
      end
      phi1=phi2;
      A1=A2;
      nx=nx+dx;      
      disp(sprintf('%1.5f', nx/length(x)));
   end
   y=y*max(abs(x))/max(abs(y));
