% function scalogram(x, nu, minfreq, maxfreq, norows, nocols)
%
% plots the scalogram of the signal x, using wavelets based on the hanning
% window.
%
% input:
%
% x       : input signal
% nu      : number of waves in one wavelet
% minfreq : lowest frequency to show
% maxfreq : highest frequency to show
% norows  : number of frequencies to show
% nocols  : number of time points to do the measurements on
%
% copyright (C) 2005 Bert Greevenbosch

function scalogram(x, nu, minfreq, maxfreq, norows, nocols)

  x=tocolumn(x);
  im=zeros(norows, nocols);
  qbanks=minfreq+(1:norows)*(maxfreq-minfreq)/norows;
  Q=Qmatrix(qbanks, nu);
  sz=size(Q);
  N=sz(2);
  step=(length(x)-N)/nocols;
  left=-round(N/2);
  right=N-1+left;
  k=1;
  
  for n=-left+1:step:length(x)-right
    ni=round(n);
    xw=Q*fftshift(x(ni+left:ni+right));
    im(:, k)=xw.*conj(xw);
    k=k+1;
    last=n;
    disp(sprintf('%1.5f', n/(length(x)-right)));
  end
  
  hold off
  setigpal
  imagesc([-left+1, last],[minfreq, maxfreq], im);
  axis('xy');
  xlabel('time (sample)');
  ylabel('frequency (rad/sample)');
  size(Q)
