% function spectrogram(x, N, T, zpad, maxfreq)
%
% creates a spectrogram plot of signal x using Fourier analysis and
% a Hanning window.
%
% x       : input signal
% N       : windowsize (must be even)
% T       : amount of time points
% zpad    : zero-padding argument: number of zeros to pad
% maxfreq : maximal frequency to show (rad/sample)
%
% copyright (C) 2005 Bert Greevenbosch

function spectrogram(x, N, T, zpad, maxfreq)

  x=torow(x);           
  w=sin((0:N-1).*pi/N).^2; % hanning window
  ds=(length(x)-N-1)/T;
  s=N/2+1;
  mf=ceil((N+zpad)*maxfreq/(2*pi));
  im=zeros(N/2+1, mf+1);

  for q=1:T
    t=round(s);
    f=fft([x(t-N/2:t+N/2-1).*w, zeros(1, zpad)]);
    f=f(1:mf+1)';
    f=f.*conj(f);
    y(:, q)=f;
    s=s+ds;
  end

  setigpal
  imagesc([0,length(x)],[0, mf*2*pi/(N+zpad)],y);
  axis('xy');
  xlabel('time (sample)');
  ylabel('frequency (rad/sample)');
