% y=trbisect(x, N, Z, overlap, stretch)
%
% implementation of the tracking vocoder using the bisection method
%
% input:
% 
% x       : input signal
% N       : window size
% Z       : number of zeros for zero padding
% overlap : overlap factor
% stretch : time-stretch factor
%
% output:
%
% y       : time-stretched signal
%
% copyright (C) 2005 Bert Greevenbosch

function y=trbisect(x, N, Z, overlap, stretch)

  global fadein;
  global fadeout;
  global tracks;

  x=torow(x);  
  window=cos((-N/2:N/2-1)*pi/N).^2;
  dnx=round((1-overlap)*N);
  nx=N/2+1+dnx;
  dny=round(dnx*stretch);
  ny=dny;
  tracks=zeros(N/2+1, 6);
  y=zeros(1, length(x)*stretch);
  fadein=-.5*cos((0:dny-1)*pi/dny)+.5;
  fadeout=.5*cos((0:dny-1)*pi/dny)+.5;  
  while(nx<length(x)-N/2-dnx)      
    [ampl2, dphi, phases]=trbisectpeak(x(nx-N/2:nx+N/2-1).*window, Z);
    trmatch(dphi, ampl2, phases, N);
    y(ny-dny+1:ny)=trreconstruct(N);
    nx=nx+dnx; 
    ny=ny+dny;
    disp(sprintf('%1.5f; %d lines', nx/length(x), length(phases)));
  end;
  
  y=y*max(abs(x))/max(abs(y));
