% function [ampl2, dphi, phases]=trbisectpeak(x, Z);
%
% applies peak detection to the signal x.
% uses the bisection method
% 
% input:
%
% x      : input signal
% Z      : number of zeros for zero-padding
%
% output:
%
% ampl2  : measured amplitudes belonging to the peaks
% dphi   : measured frequency between the peaks of the current measurement 
%          and the previous measurement
% phases : phases belongint to the peaks
%
% copyright (C) 2005 Bert Greevenbosch

function [ampl2, dphi, phases]=trbisectpeak(x, Z);

  x=torow(x);
  N=length(x);
  z=fft(fftshift([zeros(1, 0.5*Z), x, zeros(1, 0.5*Z)]));  
  y=abs(z);
  phi2=princarg(angle(z));
  k=2;
  n=0;
  ampl2=0;
  phases=0;
  dphi=0; 
  for k=2:(N+Z)/2

    if y(k-1)<y(k) & y(k+1)<=y(k) & y(k)>1
      if y(k-1)>y(k+1)
        zeta1=k-1;
        zeta2=k;
      else
        zeta1=k;
        zeta2=k+1;
      end  
      y1=abs(y(zeta1));
      y2=abs(y(zeta2));
      zeta1=(zeta1-1)*2*pi/(N+Z);
      zeta2=(zeta2-1)*2*pi/(N+Z);
  
      omega1=zeta1;
      omega2=zeta2;
      
      sg=sign(y1*ws(zeta2-omega1, N)-y2*ws(zeta1-omega1, N));
      
      for m=1:10
        xi=(omega1+omega2)/2;
        res=y1*ws(zeta2-xi, N)-y2*ws(zeta1-xi, N);
        if res==0
          break;
        end
        if res*sg>0
          omega1=xi;
        else
          omega2=xi;
        end       
        
      end
      xi=(omega1+omega2)/2;
      A = y1/ws(zeta1-xi, N);
           
      n=n+1;
      ampl2(n)=A;
      dphi(n)=xi;
      phases(n)=phi2(k);
    
    end
    
    k=k+1;

  end
