% [y1, y2]=trclarguides(x, N, Z, overlap, frac)
%
% Modification of the tracking phase vocoder with guides to extract the
% clarinet from a signal x
%
% input:
%
% x       : input signal
% N       : window size
% Z       : number of zeros to append for zero-padding
% overlap : amount of overlap between succesive measurements
% frac    : required amount of partials marked as clarinet for a line to be
%           marked as clarinet
%
% output:
%
% y1      : clarinet signal
% y2      : non-clarinet signal
%
% copyright (C) 2005 Bert Greevenbosch

function [y1, y2]=trclarguides(x, N, Z, overlap, frac)

  global fadein;
  global fadeout;
  global lines;
  global tracks;  
  global xlat;
  global y1;
  global y2;

  x=torow(x);  
  window=sin((0:N-1)*pi/N).^2;
  dn=round((1-overlap)*N);
  nx=N/2+1+dn;
  dpsi=(0:(N+Z)/2)*dn*2*pi/(N+Z);    
  [A, phi1]=calcAphi(x(1:N).*window, Z);
  tracks=zeros(N/2+1, 6);
  lines=zeros(N/2+1, 3);
  xlat=zeros(N/2+1, 1);  
  y1=zeros(1, length(x)+dn+1);
  y2=y1;
  c=1;
  fadein=-.5*cos((0:dn-1)*pi/dn)+.5;
  fadeout=.5*cos((0:dn-1)*pi/dn)+.5;
  while(nx<=length(x)-N/2+1)
    [ampl2, dphi, phi2, phases]=trpeak(x(nx-N/2:nx+N/2-1).*window, phi1, dpsi, dn, Z);
    trmatch(dphi, ampl2, phases, N);
    clar=trdetclar(N);
    trclarguidesmatch(c, dn, N, clar);
    trclarguidesreconstruct(N, frac);
    nx=nx+dn;
    c=c+1;
    phi1=princarg(phi2);
    disp(sprintf('%1.5f; %d lines', nx/length(x), length(phases)));    
  end;
  trclarguidesreconstructlast(N, frac);
  
  mul=max(abs(x))/(max(abs(y1+y2)));
  y1=y1*mul;
  y2=y2*mul; 
