% function trclarguidesmatch(c, n, N, clar)
%
% matches the partials to the guides
%
% global: tracks, lines, xlat
%
% input:
% 
% c    : number of the grain (first grain: 0, second grain: 1, ...)
% n    : number of samples between successive grains in the reconstruction
% N    : grain size of the measurements
% clar : vector containing data about which partials are part of a clarinet
%        tone.
%
% copyright (C) 2005 Bert Greevenbosch

function trclarguidesmatch(c, n, N, clar)

  global tracks;
  global lines;
  global xlat;
  
  xlatnew=zeros(N/2+1, 1);
  phases=zeros(N/2+1, 1);
  oldlen=lines(:, 2);
  for k=1:N/2+1
    bin=tracks(k, 7);
    if bin~=0                            % matched
      addr=xlat(bin);
      l=lines(addr, 2)+1;
      lines(addr, 2)=l;                  % length
      lines(addr, 3)=0;                  % sleep counter;
      lines(addr, l*2+4)=tracks(k, 4);   % frequency
      lines(addr, l*2+5)=tracks(k, 5);   % amplitude
      tracks(bin, 2)=0;                  % this bin is done
      xlatnew(k)=addr;
      phases(k)=tracks(bin, 3)+n*tracks(k, 4);            
      lines(addr, 4)=lines(addr, 4)+clar(k);        
    else
      if tracks(k, 5)~=0                 % fadein, birth of track
        addr=trguidesgetline(k);
        xlatnew(k)=addr;
        lines(addr, 1)=c;
        lines(addr, 2)=1;
        lines(addr, 3)=0;
        lines(addr, 5)=tracks(k, 6);     % phase
        lines(addr, 6)=tracks(k, 4);     % frequency
        lines(addr, 7)=tracks(k, 5);     % amplitude
        phases(k)=tracks(k, 6);           
        lines(addr, 4)=lines(addr, 4)+clar(k);        
      end        
    end
  end
  tracks(:, 1:2)=tracks(:, 4:5);  
  tracks(:, 3)=princarg(phases);
  dlen=lines(:, 2)-oldlen;
  for addr=1:N/2+1
    if dlen(addr)==0 & lines(addr, 2)~=0 % no match and length nonzero
      lines(addr, 3)=1;                  % line done
    end
  end
  xlat=xlatnew;
  for k=1:N/2+1
    if tracks(k, 5)==0
      tracks(k, 1:3)=zeros(1, 3);
    end
  end
