% function trclarguidesreconstruct(N, frac)
%
% reconstructs finished lines into the target signals
%
% global: fadein, fadeout, y1, y2, lines, xlat, tracks
%
% input:
%
% N    : size of the grain used for the measurements
% frac : minimum fraction of partials that should be considered to be a 
%        part of a clarinet tone to consider the guide to contain a
%        clarinet tone
%
% copyright (C) 2005 Bert Greevenbosch

function trclarguidesreconstruct(N, frac)

  global fadein;
  global fadeout;
  global y1;
  global y2;
  global lines;
  global xlat;
  global tracks;
  
  dny=length(fadein);
  for k=1:N/2+1
    if lines(k, 3) & lines(k, 2)>0
      x=0;
      phase=lines(k, 5);
      dphase=lines(k, 6);
      totfreq=dphase;
      A1=lines(k, 7);
      x(1:dny)=(fadein*A1).*cos(phase+(-dny:-1)*dphase);
      for m=1:lines(k, 2)-1
        A0=lines(k, m*2+5);
        A1=lines(k, m*2+7);
        dphase=lines(k, m*2+6);
        totfreq=totfreq+dphase;
        x(m*dny+1:(m+1)*dny)=(fadeout*A0+fadein*A1).*cos(phase+(0:dny-1)*dphase);
        phase=phase+dny*dphase;
      end      
      m=lines(k, 2);
      A0=lines(k, m*2+5);
      dphase=lines(k, m*2+4);
      totfreq=totfreq+dphase;
      totfreq=totfreq/(lines(k, 2)+1);
      x(m*dny+1:(m+1)*dny)=(fadeout*A0).*cos(phase+(0:dny-1)*dphase);
      if(lines(k, 4)>=m*frac) % enough marked as clarinet
        disp(sprintf('line ended: start %d; length %d; address: %d; average frequency: %1.5f (clarinet)', ...
          lines(k, 1), lines(k, 2), k, totfreq));
        y1((lines(k, 1)-1)*dny+1:lines(k, 1)*dny+m*dny)=y1((lines(k, 1)-1)*dny+1:lines(k, 1)*dny+m*dny)+x;
      else
        disp(sprintf('line ended: start %d; length %d; address: %d; average frequency: %1.5f', ...
          lines(k, 1), lines(k, 2), k, totfreq));
        y2((lines(k, 1)-1)*dny+1:lines(k, 1)*dny+m*dny)=y2((lines(k, 1)-1)*dny+1:lines(k, 1)*dny+m*dny)+x;
      end  
      lines(k, 1:4)=zeros(1, 4);
    end    
  end
