% function [y1, y2]=trclarreconstruct(clar, N)
%
% reconstructs the current partials into either the clarinet signal or the
% non-clarinet signal
%
% global: tracks, fadein, fadeout
%
% input:
%
% clar : vector containing information about which bins are clarinet bins
% N    : grain size
%
% output:
%
% y1   : clarinet grain
% y2   : non-clarinet grain
%
% copyright (C) 2005 Bert Greevenbosch


function [y1, y2]=trclarreconstruct(clar, N)

  global tracks;
  global fadein;
  global fadeout;
    
  dny=length(fadein);
  y1=zeros(1, dny);
  y2=y1;
  phases=zeros(N/2+1, 1);
  for k=1:N/2+1
     z=zeros(1, dny);
     bin=tracks(k, 7);     
     if bin~=0
        if tracks(k, 5)~=0 | tracks(bin, 2)~=0
          A0=tracks(bin, 2);
          A1=tracks(k, 5);
          phi=(0:dny-1)*tracks(k, 4)+tracks(bin, 3);
          z=(A0*fadeout+A1*fadein).*cos(phi);          
          tracks(bin, 2)=0; % this bin is done
        end        
        phases(k)=dny*tracks(k, 4)+tracks(bin, 3);
     else
        if tracks(k, 5)~=0 % fade in
           A1=tracks(k, 5);
           phi=(-dny:-1)*tracks(k, 4)+tracks(k, 6);
           z=A1*fadein.*cos(phi);
           phases(k)=tracks(k, 6); % keep this phase          
        end        
     end
     if clar(k)==1
       y1=y1+z;
     else
       y2=y2+z;
     end
  end
  for k=1:N/2+1    
     if tracks(k, 2)~=0 % frequency not done yet; fade out
        A0=tracks(k, 2);        
        phi=(0:dny-1)*tracks(k, 1)+tracks(k, 3);      
        z=A0*fadeout.*cos(phi);     
        if clar(k)==1
          y1=y1+z;
        else
          y2=y2+z;
        end
     end
  end
  tracks(:, 1:2)=tracks(:, 4:5);  
  tracks(:, 3)=princarg(phases);
  for k=1:N/2+1
    if tracks(k, 5)==0
       tracks(k, 1:3)=zeros(1, 3);
    end
  end
