% y=trguides(x, N, Z, overlap, stretch)
%
% Applies the tracking phase vocoder with guides to the signal x
%
% input:
%
% x       : input signal
% N       : window size
% Z       : number of zeros to append for zero-padding
% overlap : amount of overlap between succesive measurements
% stretch : time-stretch factor
%
% output:
%
% y       : time-stretched signal
%
% copyright (C) 2005 Bert Greevenbosch

function y=trguides(x, N, Z, overlap, stretch)

  global fadein;
  global fadeout;
  global lines;
  global tracks;  
  global xlat;
  global y;

  x=torow(x);  
  window=sin((0:N-1)*pi/N).^2;
  dnx=round((1-overlap)*N);
  dny=round(dnx*stretch);
  nx=N/2+1+dnx;
  dpsi=(0:(N+Z)/2)*dnx*2*pi/(N+Z);    
  [A, phi1]=calcAphi(x(1:N).*window, Z);
  tracks=zeros(N/2+1, 6);
  lines=zeros(N/2+1, 3);
  xlat=zeros(N/2+1, 1);  
  y=zeros(1, ceil(length(x)/dnx)*dny+dny+1);
  c=1;
  fadein=-.5*cos((0:dny-1)*pi/dny)+.5;
  fadeout=.5*cos((0:dny-1)*pi/dny)+.5;
  while(nx<=length(x)-N/2+1)
    [ampl2, dphi, phi2, phases]=trpeak(x(nx-N/2:nx+N/2-1).*window, phi1, dpsi, dnx, Z);
    trmatch(dphi, ampl2, phases, N);
    trguidesmatch(c, dny, N);
    trguidesreconstruct(N);
    nx=nx+dnx;
    c=c+1;
    phi1=princarg(phi2);
    disp(sprintf('%1.5f; %d lines', nx/length(x), length(phases)));    
  end;
  trguidesreconstructlast(N);
  
  y=y*max(abs(x))/max(abs(y));
