% function trmatch(dphi, ampl2, phases, N)
%
% matches new partials to old partials
%
% global: 
%
% tracks : data structure that contains the old and new partials
%
% input:
%
% dphi   : phase difference between current and last measurement
% ampl2  : amplitudes of current measurement
% phases : phases of current measurement
% N      : grain size
%
% copyright (C) 2005 Bert Greevenbosch

function trmatch(dphi, ampl2, phases, N);

  global tracks;  
  binsz=2*pi/N;
  tracks(:, 4:7)=zeros(N/2+1, 4);
  for n=1:length(dphi)
     k=floor(abs(dphi(n)/binsz))+1;
     if(k<=N/2+1)
       tracks(k, 4)=dphi(n);
       tracks(k, 5)=ampl2(n);
       tracks(k, 6)=phases(n);
     end
  end  
  for k=2:N/2
    if(tracks(k, 4)~=0)
      dm=abs(tracks(k, 4)-tracks(k-1, 1));
      d0=abs(tracks(k, 4)-tracks(k,   1));
      dp=abs(tracks(k, 4)-tracks(k+1, 1));
      if dm < d0 & dm < dp
        tracks(k, 7)=k-1;
        if tracks(k-1, 7)==k-1
           if abs(tracks(k-1, 4)-tracks(k-1, 1))>abs(tracks(k, 4)-tracks(k-1, 1))
             tracks(k-1, 7)=0;
           else
             tracks(k, 7)=0;
           end
        end
        if k>2
          if tracks(k-2, 7)==k-1
            if abs(tracks(k-2, 4)-tracks(k-1, 1))>abs(tracks(k, 4)-tracks(k-1, 4))
              tracks(k-2, 7)=0;
            else
              tracks(k, 7)=0;
            end
          end
        end
      end
      if d0 <= dm & d0 <= dp
        tracks(k, 7)=k;
        if tracks(k-1, 7)==k
          if abs(tracks(k-1, 4)-tracks(k, 1))>abs(tracks(k, 4)-tracks(k, 1))
            tracks(k-1, 7)=0;
          else
            tracks(k, 7)=0;
          end
        end           
      end
      if dp < dm & dp < d0
        tracks(k, 7)=k+1;
      end     
    end
  end  
  for k=1:N/2     
    if tracks(k, 7)~=0 & tracks(k, 4)~=0 % matched?
      bin=tracks(k, 7);
      if tracks(bin, 1)==0 | tracks(bin, 2)==0 % matched to zero?
        tracks(k, 7)=0;   % not matched
      end
    end
  end  
