% function [ampl2, dphi, phi2, phases]=trpeak(x, phi1, dpsi, dn, Z);
%
% applies peak detection to the signal x, by looking at the phase
% difference
% 
% input:
%
% x      : input signal
% phi1   : phases of previous measurements
% dpsi   : frequency between previous measurements and current measurement
% dn     : number of samples between successive measurements
% Z      : number of zeros for zero-padding
%
% output:
%
% ampl2  : measured amplitudes belonging to the peaks
% dphi   : measured frequency between the peaks of the current measurement 
%          and the previous measurement
% phi2   : phases of all frequency bins
% phases : phases belongint to the peaks
%
% copyright (C) 2005 Bert Greevenbosch

function [ampl2, dphi, phi2, phases]=trpeak(x, phi1, dpsi, dn, Z);

  N=length(x);
  [A, phi2]=calcAphi(x, Z);
  psi=phi1+dpsi;
  phi2=psi+princarg(phi2-psi);  
  dfreq=(phi2-phi1)/dn;
  m=1;
  ampl2=0;
  phases=0;
  for k=2:(N+Z)/2
    if A(k-1)<A(k) & A(k+1)<=A(k) & A(k)>1
      ampl2(m)=A(k);
      dphi(m)=dfreq(k);
      phases(m)=phi1(k);
      m=m+1;
    end
  end
  m=m-1;
  ampl2=ampl2(1:m);
  dphi=dphi(1:m);
  phases=phases(1:m);