% y=trvoc(x, N, Z, overlap, stretch)
%
% input:
%
% x       : input signal
% N       : window size
% Z       : number of zeros for zero padding
% overlap : overlap factor
% stretch : time-stretch factor
%
% output:
%
% y       : time-stretched signal
%
% copyright (C) 2005 Bert Greevenbosch

function y=trvoc(x, N, Z, overlap, stretch)

  global fadein;
  global fadeout;
  global tracks;

  x=torow(x);  
  window=sin((0:N-1)*pi/N).^2;
  dnx=round((1-overlap)*N);
  nx=N/2+1+dnx;
  dny=round(dnx*stretch);
  ny=dny;
  dpsi=(0:(N+Z)/2)*dnx*2*pi/(N+Z);    
  [A, phi1]=calcAphi(x(1:N).*window, Z);
  tracks=zeros(N/2+1, 6);
  y=zeros(1, length(x)*stretch);
  fadein=-.5*cos((0:dny-1)*pi/dny)+.5;
  fadeout=.5*cos((0:dny-1)*pi/dny)+.5;  
  while(nx<length(x)-N/2-dnx)      
    [ampl2, dphi, phi2, phases]=trpeak(x(nx-N/2:nx+N/2-1).*window, phi1, dpsi, dnx, Z);
    trmatch(dphi, ampl2, phases, N);
    y(ny-dny+1:ny)=trreconstruct(N);
    nx=nx+dnx; 
    ny=ny+dny;
    phi1=princarg(phi2);
    disp(sprintf('%1.5f; %d lines', nx/length(x), length(phases)));
  end;
  
  y=y*max(abs(x))/max(abs(y));
